InterpMethod

Enum InterpMethod 

pub enum InterpMethod {
    Linear,
    Left,
    Right,
    Nearest,
}
Interpolation method for sequence lookups

Variants



Linear

Linear interpolation inside the grid. Outside the grid, the nearest value is held constant to prevent runaway extrapolation.



Left

Hold the value on the left side of the current cell.

Hold-left is the default because intermediate values may not be valid values in some cases, while the values at the control points are valid to the extent that the user’s intent is valid.



Right

Hold the value on the right side of the current cell.



Nearest

Hold the nearest value to the left or right of the current cell.

Implementations

Source

impl InterpMethod

pub fn try_parse(s: &str) -> Result<Self, String>

Attempt to parse a string into an interpolation method. Case-insensitive and discards whitespace.

pub fn to_str(&self) -> &'static str

Simple string representation compatible with Self::try_parse