Calc

Trait Calc 

pub trait Calc:
    Send
    + Sync
    + Debug
    + Serialize
    + Deserialize {
    // Required methods
    fn init(
        &mut self,
        ctx: ControllerCtx,
        input_indices: Vec<usize>,
        output_range: Range<usize>,
    ) -> Result<(), String>;
    fn terminate(&mut self) -> Result<(), String>;
    fn eval(&mut self, tape: &mut [f64]) -> Result<(), String>;
    fn get_input_map(&self) -> BTreeMap<CalcInputName, FieldName>;
    fn update_input_map(
        &mut self,
        field: &str,
        source: &str,
    ) -> Result<(), String>;
    fn get_save_outputs(&self) -> bool;
    fn set_save_outputs(&mut self, save_outputs: bool);
    fn get_config(&self) -> BTreeMap<String, f64>;
    fn set_config(&mut self, cfg: &BTreeMap<String, f64>) -> Result<(), String>;
    fn get_input_names(&self) -> Vec<CalcInputName> ;
    fn get_output_names(&self) -> Vec<CalcOutputName> ;

    // Provided method
    fn kind(&self) -> String { ... }
}
A calculation that takes some inputs and produces some outputs at each timestep, and may have some persistent internal state.

Required Methods

fn init( &mut self, ctx: ControllerCtx, input_indices: Vec<usize>, output_range: Range<usize>, ) -> Result<(), String>

Reset internal state and register calc tape indices

fn terminate(&mut self) -> Result<(), String>

Clear state to reset for another run

fn eval(&mut self, tape: &mut [f64]) -> Result<(), String>

Run calcs for a cycle

fn get_input_map(&self) -> BTreeMap<CalcInputName, FieldName>

Map from input field names (like v, without prefix) to the state name that the input should draw from (like peripheral_0.output_1, with prefix)

fn update_input_map(&mut self, field: &str, source: &str) -> Result<(), String>

Change a value in the input map

fn get_save_outputs(&self) -> bool

Get flag for whether to save outputs

fn set_save_outputs(&mut self, save_outputs: bool)

Set flag for whether to save outputs

fn get_config(&self) -> BTreeMap<String, f64>

Get config field values

fn set_config(&mut self, cfg: &BTreeMap<String, f64>) -> Result<(), String>

Apply config field values

fn get_input_names(&self) -> Vec<CalcInputName>

List of input field names in the order that they will be consumed

fn get_output_names(&self) -> Vec<CalcOutputName>

List of output field names in the order that they will be written out

Provided Methods

fn kind(&self) -> String

Get the type name, which is guaranteed to be unique among implementations of the trait because of the use of a global vtable for serialization, and guaranteed not to include non-’static lifetimes due to trait bounds.