Module channel

Module channel 

Serializable thread channel to allow user sideloading of comms between the controller’s appendages

Structs

Channel
A multiple-producer, multiple-consumer (MPMC) bidirectional message pipe that will be reinitialized (but not reconnected to any particular endpoints) when deserialized.
Endpoint
Channel endpoint for either a source or sink.

Enums

Msg
A basic set of message types that can be passed along a user channel