Termination

Enum Termination 

#[non_exhaustive]
pub enum Termination { Timeout(Duration), Scheduled(SystemTime), }
Criteria for exiting the control program

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Timeout(Duration)

A duration after which the control program should terminate. The controller will use the monotonic clock, not system realtime clock, to determine when this threshold occurs; as a result, if used for scheduling relative to a “realtime” date or time, it will accumulate some error as the monotonic clock drifts.



Scheduled(SystemTime)

Schedule termination at a specific “realtime” date or time.

Implementations

Source

impl Termination

pub fn timeout_s(s: f64) -> Self

pub fn scheduled_epoch_ns(ns: u64) -> PyResult<Self>