pub struct Snapshot {
pub system_time: String,
pub timestamp: i64,
pub values: HashMap<String, f64>,
}Expand description
A snapshot of the values from all peripherals and calcs at the end of a cycle.
Fields
system_time: StringCycle-end UTC system time in RFC3339 format with nanoseconds.
timestamp: i64[ns] Cycle-end time in nanoseconds since the start of run.
values: HashMap<String, f64>Map of the latest readings from all peripherals and calcs.