pub struct PeripheralId {
pub model_number: u64,
pub serial_number: u64,
}Expand description
Unique identifier that combines model number and serial number. Only one individual unit will have a given peripheral ID.
Fields
model_number: u64serial_number: u64Trait Implementations
Sourceimpl ByteStruct for PeripheralId
impl ByteStruct for PeripheralId
Sourcefn write_bytes(&self, bytes: &mut [u8])
fn write_bytes(&self, bytes: &mut [u8])
Packs the struct into raw bytes and write to a slice
Sourcefn read_bytes(bytes: &[u8]) -> PeripheralId
fn read_bytes(bytes: &[u8]) -> PeripheralId
Unpacks raw bytes from a slice into a new struct
Sourceimpl ByteStructLen for PeripheralId
impl ByteStructLen for PeripheralId
Sourceimpl Clone for PeripheralId
impl Clone for PeripheralId
Sourcefn clone(&self) -> PeripheralId
fn clone(&self) -> PeripheralId
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeripheralId
impl Debug for PeripheralId
Sourceimpl Default for PeripheralId
impl Default for PeripheralId
Sourcefn default() -> PeripheralId
fn default() -> PeripheralId
Returns the “default value” for a type. Read more
Sourceimpl Ord for PeripheralId
impl Ord for PeripheralId
Sourcefn cmp(&self, other: &PeripheralId) -> Ordering
fn cmp(&self, other: &PeripheralId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PeripheralId
impl PartialEq for PeripheralId
Sourceimpl PartialOrd for PeripheralId
impl PartialOrd for PeripheralId
impl Copy for PeripheralId
impl Eq for PeripheralId
impl StructuralPartialEq for PeripheralId