pub enum InterpMethod {
Linear,
Left,
Right,
Nearest,
}Expand description
Interpolation method for sequence lookups
Variants
Linear
Linear interpolation inside the grid. Outside the grid, the nearest value is held constant to prevent runaway extrapolation.
Left
Hold the value on the left side of the current cell.
Hold-left is the default because intermediate values may not be valid values in some cases, while the values at the control points are valid to the extent that the user’s intent is valid.
Right
Hold the value on the right side of the current cell.
Nearest
Hold the nearest value to the left or right of the current cell.
Implementations