Control loop and integration with data pipeline and calc orchestrator
Modules
- channel
- Serializable thread channel to allow user sideloading of comms between the controller’s appendages
- context
- Information about the current operation that may be used by the controller’s appendages.
Structs
- Controller
- The controller implements the control loop, synchronizes sample reporting time between the peripherals, and dispatches measured data, calculations, and metrics to the data pipeline.
- CsvReplay
Source - CSV-backed replay source.
- Replay
Cycle - One replayed controller cycle.
- RunHandle
- A handle to a
super::Controllerrunning viasuper::Controller::run_nonblockingthat allows reading and writing values from outside the control program during operation and signaling the controller to shut down. - Snapshot
- A snapshot of the values from all peripherals and calcs at the end of a cycle.
Traits
- Replay
Source - Source of raw peripheral outputs for
crate::Controller::replay.
Type Aliases
- Manual
Input Map - Peripheral inputs set manually from outside the control program.