Module controller

Module controller 

Control loop and integration with data pipeline and calc orchestrator

Modules

channel
Serializable thread channel to allow user sideloading of comms between the controller’s appendages
context
Information about the current operation that may be used by the controller’s appendages.

Structs

Controller
The controller implements the control loop, synchronizes sample reporting time between the peripherals, and dispatches measured data, calculations, and metrics to the data pipeline.
RunHandle
A handle to a [Controller] running via [Controller::run_nonblocking] that allows reading and writing values from outside the control program during operation and signaling the controller to shut down.
Snapshot
A snapshot of the values from all peripherals and calcs at the end of a cycle.

Type Aliases

ManualInputMap
Peripheral inputs set manually from outside the control program.