#[non_exhaustive]pub struct ControllerCtx {Show 16 fields
pub op_name: String,
pub op_dir: PathBuf,
pub dt_ns: u32,
pub timeout_to_operating_ns: u32,
pub binding_timeout_ms: u16,
pub configuring_timeout_ms: u16,
pub peripheral_loss_of_contact_limit: u16,
pub controller_loss_of_contact_limit: u16,
pub termination_criteria: Option<Termination>,
pub loss_of_contact_policy: LossOfContactPolicy,
pub loop_method: LoopMethod,
pub user_ctx: BTreeMap<String, String>,
pub user_channels: Arc<RwLock<BTreeMap<String, Channel>>>,
pub manual_inputs: ManualInputMap,
pub enable_manual_inputs: bool,
pub channel_units: Vec<Option<String>>,
}Expand description
Operation context, provided to appendages during init
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.op_name: StringA name for this controller op, which will be used as the name of the file/table/bucket/etc of each data dispatcher and must be compatible with that use.
op_dir: PathBufA directory to find file inputs and place outputs.
dt_ns: u32Control cycle period in nanoseconds
timeout_to_operating_ns: u32Delay from end of configuration window after which the peripherals time out to the Operating state
binding_timeout_ms: u16Duration to wait for responses to binding
configuring_timeout_ms: u16Duration for peripherals to wait to receive configuration after being bound
peripheral_loss_of_contact_limit: u16Number of consecutive missed control inputs after which the peripheral should assume contact has been lost, de-energize their outputs, and wait to bind a controller again.
controller_loss_of_contact_limit: u16Number of consecutive missed responses from a peripheral after which the controller should assume contact has been lost
termination_criteria: Option<Termination>A condition for exiting the control loop, to be checked at each cycle
loss_of_contact_policy: LossOfContactPolicyResponse to losing contact with a peripheral
loop_method: LoopMethodWhether to prioritize performance or efficiency in the control loop.
user_ctx: BTreeMap<String, String>An escape hatch for sideloading user context (likely json-encoded) that is not yet implemented as a standalone field.
user_channels: Arc<RwLock<BTreeMap<String, Channel>>>An escape hatch for sideloading communication between appendages. Each channel is a bidirectional MPMC message pipe.
Because bidirectional channels may not close until the program terminates on its own, the status of these channels should not be used to indicate when a freerunning thread should terminate, as this will often result in a resource leak.
manual_inputs: ManualInputMapManual input overrides that can be written while the controller is running.
enable_manual_inputs: boolWhether manual input overrides should be applied during the control loop.
channel_units: Vec<Option<String>>Units for each dispatched channel, in the same order as channel_names.
None indicates the unit is unknown or dimensionless.
Populated by the controller assembly pass before dispatchers are initialized.
#[serde(default)] so snapshots serialized before this field was added deserialize
to an empty Vec and are re-populated by the assembly pass.
Implementations
Sourceimpl ControllerCtx
impl ControllerCtx
Sourcepub fn source_endpoint(&self, channel_name: &str) -> Endpoint
pub fn source_endpoint(&self, channel_name: &str) -> Endpoint
Get a handle to a source endpoint tx/rx pair for the channel, creating the channel if it does not exist.
Sourcepub fn sink_endpoint(&self, channel_name: &str) -> Endpoint
pub fn sink_endpoint(&self, channel_name: &str) -> Endpoint
Get a handle to a sink endpoint tx/rx pair for the channel, creating the channel if it does not exist.