Packetized socket interface for message-passing to/from peripherals on different I/O media.
Modules
- udp
- Implementation of SuperSocket trait for stdlib UDP socket on IPV4
- unix
- Implementation of SuperSocket trait for stdlib unix datagram socket, which provides inter-process communication for peripherals that are defined in software, or a bridge to an arbitrary data source.
Traits
- Super
Socket - Packetized socket interface for message-passing to/from peripherals on different I/O media.
Type Aliases
- Super
Socket Addr - Address of a peripheral that is communicating on a socket
- Super
Socket Id - Socket index